==> krita-3.1.0.tar.gz: krita-3.1.0/README.md <==
![Picture](https://krita.org/wp-content/uploads/2016/04/krita_logo_200-ef21fd67a8add4f0.png)

Krita is a free and open source digital painting application. It is for artists who want to create professional work from start to end. Krita is used by comic book artists, illustrators, concept artists, matte and texture painters and in the digital VFX industry.

If you are reading this on Github, be aware that this is just a mirror. Our real
code repository is provided by KDE:  https://phabricator.kde.org/diffusion/KRITA/

This repository contains the current, Qt5-based, development version of Krita 3. Krita 3.0 has been released and development on Krita 2.9 has stopped.  Krita 2.9 was part of Calligra: https://phabricator.kde.org/diffusion/CALLIGRA/

![Picture] (https://krita.org/wp-content/uploads/2016/04/krita-30-screenshot.jpg)


### User Manual
https://docs.krita.org/Category:User_Manual

### Development Notes and Build Instructions
If you're building on Windows or OSX you'll need to build some third-party dependencies first. You should look at the README in the 3rdparty folder for directions. 

If you're building on Linux, please follow David Revoy's Cat Guide: http://www.davidrevoy.com/article193/guide-building-krita-on-linux-for-cats

### Bugs and Wishes

https://bugs.kde.org/buglist.cgi?bug_status=UNCONFIRMED&bug_status=CONFIRMED&bug_status=ASSIGNED&bug_status=REOPENED&list_id=1315444&product=krita&query_format=advanced

### Discussion Forum
http://forum.kde.org/viewforum.php?f=136

### IRC channel
Most of the developers hang out here. If you are interested in helping with the project this is a great place to start. Many of the developers based in Europe so they may be offline depending on when you join.

irc.freenode.net, #krita

### Project Website

  http://www.krita.org

==> krita_3.1.2.1.orig.tar.gz: krita-3.1.2.1/README.md <==
![Picture](https://krita.org/wp-content/uploads/2016/04/krita_logo_200-ef21fd67a8add4f0.png)

Krita is a free and open source digital painting application. It is for artists who want to create professional work from start to end. Krita is used by comic book artists, illustrators, concept artists, matte and texture painters and in the digital VFX industry.

If you are reading this on Github, be aware that this is just a mirror. Our real
code repository is provided by KDE: https://phabricator.kde.org/source/krita/ 

This repository contains the current, Qt5-based, development version of Krita 3. Krita 3.0 has been released and development on Krita 2.9 has stopped.  Krita 2.9 was part of Calligra: https://phabricator.kde.org/source/krita/

![Picture] (https://krita.org/wp-content/uploads/2016/04/krita-30-screenshot.jpg)


### User Manual
https://docs.krita.org/Category:User_Manual

### Development Notes and Build Instructions
If you're building on Windows or OSX you'll need to build some third-party dependencies first. You should look at the README in the 3rdparty folder for directions. 

If you're building on Linux, please follow David Revoy's Cat Guide: http://www.davidrevoy.com/article193/guide-building-krita-on-linux-for-cats

### Bugs and Wishes

https://bugs.kde.org/buglist.cgi?bug_status=UNCONFIRMED&bug_status=CONFIRMED&bug_status=ASSIGNED&bug_status=REOPENED&list_id=1315444&product=krita&query_format=advanced

### Discussion Forum
http://forum.kde.org/viewforum.php?f=136

### IRC channel
Most of the developers hang out here. If you are interested in helping with the project this is a great place to start. Many of the developers based in Europe so they may be offline depending on when you join.

irc.freenode.net, #krita

### Project Website

  http://www.krita.org
